import ast
import unittest

import flake8_import_style


class I8Test(unittest.TestCase):

    def test_run(self):

        tree = ast.parse("import mod")
        i8 = flake8_import_style.I8(tree)
        self.assertEqual(list(i8.run()), [])

        tree = ast.parse("import mod as mod1")
        i8 = flake8_import_style.I8(tree)
        self.assertEqual(list(i8.run()), [])

        tree = ast.parse("from . import obj")
        i8 = flake8_import_style.I8(tree)
        self.assertEqual(list(i8.run()), [(
            1,
            0,
            "I801 use 'import ...' instead of 'from ... import obj'",
            "I801",
        )])

        tree = ast.parse("from .. import obj")
        i8 = flake8_import_style.I8(tree)
        self.assertEqual(list(i8.run()), [(
            1,
            0,
            "I801 use 'import ...' instead of 'from ... import obj'",
            "I801",
        )])

        tree = ast.parse("from mod import obj")
        i8 = flake8_import_style.I8(tree)
        self.assertEqual(list(i8.run()), [(
            1,
            0,
            "I801 use 'import mod' instead of 'from mod import obj'",
            "I801",
        )])



import ast

import pkg_resources


I801 = "I801 use 'import {module}' instead of 'from {module} import {names}'"


class I8(object):
    """Complain about all "from x import y" style imports."""

    name = "import-style"
    version = pkg_resources.get_distribution(__package__).version

    def __init__(self, tree):
        self.tree = tree

    def run(self):
        for i in ast.walk(self.tree):
            if isinstance(i, ast.ImportFrom):
                message = I801.format(
                    module=(i.module or "..."),
                    names=", ".join(i.name for i in i.names))
                yield (i.lineno, i.col_offset, message, "I801")



import os.path
import setuptools


here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "DESCRIPTION.rst")) as f:
    long_description = f.read()

setuptools.setup(
    name="flake8-import-style", version="0.3.0",
    description="A flake8 plugin to ensure explicit module imports",
    long_description=long_description,
    packages=setuptools.find_packages(),
    author="Stefano Palazzo",
    author_email="stefano.palazzo@gmail.com",
    url="https://github.com/sfstpala/flake8-import-style",
    license="ISC",
    install_requires=[
        "setuptools",
    ],
    test_suite="flake8_import_style.tests",
    entry_points={
        "flake8.extension": [
            "I8 = flake8_import_style:I8",
        ],
    },
    classifiers=[
        "Framework :: Flake8",
        "License :: OSI Approved :: ISC License (ISCL)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Quality Assurance",
    ],
)
